[![PyPI version](https://badge.fury.io/py/pyspral.svg)](https://badge.fury.io/py/pyspral)

# PySPRAL

`PySPRAL` consists of python bindings to the [Sparse Parallel Robust Algorithms Library](https://github.com/ralna/spral) library.

## Installation

`PySPRAL` can be install directly from PyPI using `pip`, provided that `SPRAL` itself is already installed.

## Package Support

So far, the following packages are supported:

- `RANDOM_MATRIX`: Yes
- `SCALING`: Yes
- `RUTHERFORD-BOEING`: Yes
- `SSIDS`: Yes
- `SSMFE`: Partial (computation of simple eigenvalues without shifting)
- `LSMR`: Yes
